@@ -117,7 +117,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	}
 
 	/**
-	 * @access public
 	 */
 	public function no_items() {
 		_e( 'No users found.' );
@@ -135,11 +134,11 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 		$super_admins = get_super_admins();
 		$total_admins = count( $super_admins );
 
-		$class = $role != 'super' ? ' class="current"' : '';
+		$current_link_attributes = $role !== 'super' ? ' class="current" aria-current="page"' : '';
 		$role_links = array();
-		$role_links['all'] = "<a href='" . network_admin_url('users.php') . "'$class>" . sprintf( _nx( 'All <span class="count">(%s)</span>', 'All <span class="count">(%s)</span>', $total_users, 'users' ), number_format_i18n( $total_users ) ) . '</a>';
-		$class = $role === 'super' ? ' class="current"' : '';
-		$role_links['super'] = "<a href='" . network_admin_url('users.php?role=super') . "'$class>" . sprintf( _n( 'Super Admin <span class="count">(%s)</span>', 'Super Admins <span class="count">(%s)</span>', $total_admins ), number_format_i18n( $total_admins ) ) . '</a>';
+		$role_links['all'] = "<a href='" . network_admin_url( 'users.php' ) . "'$current_link_attributes>" . sprintf( _nx( 'All <span class="count">(%s)</span>', 'All <span class="count">(%s)</span>', $total_users, 'users' ), number_format_i18n( $total_users ) ) . '</a>';
+		$current_link_attributes = $role === 'super' ? ' class="current" aria-current="page"' : '';
+		$role_links['super'] = "<a href='" . network_admin_url( 'users.php?role=super' ) . "'$current_link_attributes>" . sprintf( _n( 'Super Admin <span class="count">(%s)</span>', 'Super Admins <span class="count">(%s)</span>', $total_admins ), number_format_i18n( $total_admins ) ) . '</a>';
 
 		return $role_links;
 	}
@@ -175,7 +174,7 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 		/**
 		 * Filters the columns displayed in the Network Admin Users list table.
 		 *
-		 * @since MU
+		 * @since MU (3.0.0)
 		 *
 		 * @param array $users_columns An array of user columns. Default 'cb', 'username',
 		 *                             'name', 'email', 'registered', 'blogs'.
@@ -200,7 +199,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Handles the checkbox column output.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param WP_User $user The current WP_User object.
 	 */
@@ -218,7 +216,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Handles the ID column output.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param WP_User $user The current WP_User object.
 	 */
@@ -230,7 +227,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Handles the username column output.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param WP_User $user The current WP_User object.
 	 */
@@ -243,7 +239,7 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 
 		?><strong><a href="<?php echo $edit_link; ?>" class="edit"><?php echo $user->user_login; ?></a><?php
 		if ( in_array( $user->user_login, $super_admins ) ) {
-			echo ' - ' . __( 'Super Admin' );
+			echo ' &mdash; ' . __( 'Super Admin' );
 		}
 		?></strong>
 	<?php
@@ -253,19 +249,21 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Handles the name column output.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param WP_User $user The current WP_User object.
 	 */
 	public function column_name( $user ) {
-		echo "$user->first_name $user->last_name";
+		if ( $user->first_name && $user->last_name ) {
+			echo "$user->first_name $user->last_name";
+		} else {
+			echo '<span aria-hidden="true">&#8212;</span><span class="screen-reader-text">' . _x( 'Unknown', 'name' ) . '</span>';
+		}
 	}
 
 	/**
 	 * Handles the email column output.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param WP_User $user The current WP_User object.
 	 */
@@ -277,7 +275,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Handles the registered date column output.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @global string $mode List table view mode.
 	 *
@@ -295,7 +292,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 
 	/**
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @param WP_User $user
 	 * @param string  $classes
@@ -313,7 +309,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Handles the sites column output.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param WP_User $user The current WP_User object.
 	 */
@@ -378,7 +373,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Handles the default column output.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param WP_User $user       The current WP_User object.
 	 * @param string $column_name The current column name.
@@ -412,7 +406,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Gets the name of the default primary column.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @return string Name of the default primary column, in this case, 'username'.
 	 */
@@ -424,7 +417,6 @@ class WP_MS_Users_List_Table extends WP_List_Table {
 	 * Generates and displays row action links.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @param object $user        User being acted upon.
 	 * @param string $column_name Current column name.
