@@ -53,25 +53,23 @@ if ( ! current_user_can( $capability ) ) {
 }
 
 // Handle admin email change requests
-if ( is_multisite() ) {
-	if ( ! empty($_GET[ 'adminhash' ] ) ) {
-		$new_admin_details = get_option( 'adminhash' );
-		$redirect = 'options-general.php?updated=false';
-		if ( is_array( $new_admin_details ) && hash_equals( $new_admin_details[ 'hash' ], $_GET[ 'adminhash' ] ) && !empty($new_admin_details[ 'newemail' ]) ) {
-			update_option( 'admin_email', $new_admin_details[ 'newemail' ] );
-			delete_option( 'adminhash' );
-			delete_option( 'new_admin_email' );
-			$redirect = 'options-general.php?updated=true';
-		}
-		wp_redirect( admin_url( $redirect ) );
-		exit;
-	} elseif ( ! empty( $_GET['dismiss'] ) && 'new_admin_email' == $_GET['dismiss'] ) {
-		check_admin_referer( 'dismiss-' . get_current_blog_id() . '-new_admin_email' );
+if ( ! empty( $_GET[ 'adminhash' ] ) ) {
+	$new_admin_details = get_option( 'adminhash' );
+	$redirect = 'options-general.php?updated=false';
+	if ( is_array( $new_admin_details ) && hash_equals( $new_admin_details[ 'hash' ], $_GET[ 'adminhash' ] ) && ! empty( $new_admin_details[ 'newemail' ] ) ) {
+		update_option( 'admin_email', $new_admin_details[ 'newemail' ] );
 		delete_option( 'adminhash' );
 		delete_option( 'new_admin_email' );
-		wp_redirect( admin_url( 'options-general.php?updated=true' ) );
-		exit;
+		$redirect = 'options-general.php?updated=true';
 	}
+	wp_redirect( admin_url( $redirect ) );
+	exit;
+} elseif ( ! empty( $_GET['dismiss'] ) && 'new_admin_email' == $_GET['dismiss'] ) {
+	check_admin_referer( 'dismiss-' . get_current_blog_id() . '-new_admin_email' );
+	delete_option( 'adminhash' );
+	delete_option( 'new_admin_email' );
+	wp_redirect( admin_url( 'options-general.php?updated=true' ) );
+	exit;
 }
 
 if ( is_multisite() && ! current_user_can( 'manage_network_options' ) && 'update' != $action ) {
@@ -83,7 +81,7 @@ if ( is_multisite() && ! current_user_can( 'manage_network_options' ) && 'update
 }
 
 $whitelist_options = array(
-	'general' => array( 'blogname', 'blogdescription', 'gmt_offset', 'date_format', 'time_format', 'start_of_week', 'timezone_string', 'WPLANG' ),
+	'general' => array( 'blogname', 'blogdescription', 'gmt_offset', 'date_format', 'time_format', 'start_of_week', 'timezone_string', 'WPLANG', 'new_admin_email' ),
 	'discussion' => array( 'default_pingback_flag', 'default_ping_status', 'default_comment_status', 'comments_notify', 'moderation_notify', 'comment_moderation', 'require_name_email', 'comment_whitelist', 'comment_max_links', 'moderation_keys', 'blacklist_keys', 'show_avatars', 'avatar_rating', 'avatar_default', 'close_comments_for_old_posts', 'close_comments_days_old', 'thread_comments', 'thread_comments_depth', 'page_comments', 'comments_per_page', 'default_comments_page', 'comment_order', 'comment_registration' ),
 	'media' => array( 'thumbnail_size_w', 'thumbnail_size_h', 'thumbnail_crop', 'medium_size_w', 'medium_size_h', 'large_size_w', 'large_size_h', 'image_default_size', 'image_default_align', 'image_default_link_type' ),
 	'reading' => array( 'posts_per_page', 'posts_per_rss', 'rss_use_excerpt', 'show_on_front', 'page_on_front', 'page_for_posts', 'blog_public' ),
@@ -107,7 +105,6 @@ if ( !is_multisite() ) {
 	if ( !defined( 'WP_HOME' ) )
 		$whitelist_options['general'][] = 'home';
 
-	$whitelist_options['general'][] = 'admin_email';
 	$whitelist_options['general'][] = 'users_can_register';
 	$whitelist_options['general'][] = 'default_role';
 
@@ -122,8 +119,6 @@ if ( !is_multisite() ) {
 		$whitelist_options['media'][] = 'upload_url_path';
 	}
 } else {
-	$whitelist_options['general'][] = 'new_admin_email';
-
 	/**
 	 * Filters whether the post-by-email functionality is enabled.
 	 *
@@ -181,15 +176,13 @@ if ( 'update' == $action ) {
 			$_POST['timezone_string'] = '';
 		}
 
-		// Handle translation install.
-		if ( ! empty( $_POST['WPLANG'] ) && ( ! is_multisite() || is_super_admin() ) ) { // @todo: Skip if already installed
+		// Handle translation installation.
+		if ( ! empty( $_POST['WPLANG'] ) && current_user_can( 'install_languages' ) ) {
 			require_once( ABSPATH . 'wp-admin/includes/translation-install.php' );
 
-			if ( wp_can_install_language_pack() ) {
-				$language = wp_download_language_pack( $_POST['WPLANG'] );
-				if ( $language ) {
-					$_POST['WPLANG'] = $language;
-				}
+			$language = wp_download_language_pack( $_POST['WPLANG'] );
+			if ( $language ) {
+				$_POST['WPLANG'] = $language;
 			}
 		}
 	}
