@@ -18,7 +18,9 @@
  */
 class WP_Customize_Setting {
 	/**
-	 * @access public
+	 * Customizer bootstrap instance.
+	 *
+	 * @since 3.4.0
 	 * @var WP_Customize_Manager
 	 */
 	public $manager;
@@ -26,13 +28,15 @@ class WP_Customize_Setting {
 	/**
 	 * Unique string identifier for the setting.
 	 *
-	 * @access public
+	 * @since 3.4.0
 	 * @var string
 	 */
 	public $id;
 
 	/**
-	 * @access public
+	 * Type of customize settings.
+	 *
+	 * @since 3.4.0
 	 * @var string
 	 */
 	public $type = 'theme_mod';
@@ -40,27 +44,62 @@ class WP_Customize_Setting {
 	/**
 	 * Capability required to edit this setting.
 	 *
-	 * @var string
+	 * @since 3.4.0
+	 * @var string|array
 	 */
 	public $capability = 'edit_theme_options';
 
 	/**
 	 * Feature a theme is required to support to enable this setting.
 	 *
-	 * @access public
+	 * @since 3.4.0
 	 * @var string
 	 */
-	public $theme_supports  = '';
-	public $default         = '';
-	public $transport       = 'refresh';
+	public $theme_supports = '';
 
 	/**
-	 * Server-side sanitization callback for the setting's value.
+	 * The default value for the setting.
 	 *
-	 * @var callback
+	 * @since 3.4.0
+	 * @var string
+	 */
+	public $default = '';
+
+	/**
+	 * Options for rendering the live preview of changes in Theme Customizer.
+	 *
+	 * Set this value to 'postMessage' to enable a custom Javascript handler to render changes to this setting
+	 * as opposed to reloading the whole page.
+	 *
+	 * @link https://developer.wordpress.org/themes/customize-api
+	 *
+	 * @since 3.4.0
+	 * @var string
+	 */
+	public $transport = 'refresh';
+
+	/**
+	 * Server-side validation callback for the setting's value.
+	 *
+	 * @since 4.6.0
+	 * @var callable
+	 */
+	public $validate_callback = '';
+
+	/**
+	 * Callback to filter a Customize setting value in un-slashed form.
+	 *
+	 * @since 3.4.0
+	 * @var callable
+	 */
+	public $sanitize_callback = '';
+
+	/**
+	 * Callback to convert a Customize PHP setting value to a value that is JSON serializable.
+	 *
+	 * @since 3.4.0
+	 * @var string
 	 */
-	public $validate_callback    = '';
-	public $sanitize_callback    = '';
 	public $sanitize_js_callback = '';
 
 	/**
@@ -72,12 +111,14 @@ class WP_Customize_Setting {
 	 * from the start.
 	 *
 	 * @since 4.2.0
-	 * @access public
 	 * @var bool
 	 */
 	public $dirty = false;
 
 	/**
+	 * ID Data.
+	 *
+	 * @since 3.4.0
 	 * @var array
 	 */
 	protected $id_data = array();
@@ -86,7 +127,6 @@ class WP_Customize_Setting {
 	 * Whether or not preview() was called.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 * @var bool
 	 */
 	protected $is_previewed = false;
@@ -95,9 +135,8 @@ class WP_Customize_Setting {
 	 * Cache of multidimensional values to improve performance.
 	 *
 	 * @since 4.4.0
-	 * @access protected
-	 * @var array
 	 * @static
+	 * @var array
 	 */
 	protected static $aggregated_multidimensionals = array();
 
@@ -105,7 +144,6 @@ class WP_Customize_Setting {
 	 * Whether the multidimensional setting is aggregated.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 * @var bool
 	 */
 	protected $is_multidimensional_aggregated = false;
@@ -168,7 +206,6 @@ class WP_Customize_Setting {
 	 * Get parsed ID data for multidimensional setting.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @return array {
 	 *     ID data for multidimensional setting.
@@ -188,7 +225,6 @@ class WP_Customize_Setting {
 	 * calls get combined into one call, greatly improving performance.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 */
 	protected function aggregate_multidimensional() {
 		$id_base = $this->id_data['base'];
@@ -216,7 +252,6 @@ class WP_Customize_Setting {
 	 * This is intended only for use by unit tests.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @ignore
 	 */
 	static public function reset_aggregated_multidimensionals() {
@@ -227,7 +262,6 @@ class WP_Customize_Setting {
 	 * The ID for the current site when the preview() method was called.
 	 *
 	 * @since 4.2.0
-	 * @access protected
 	 * @var int
 	 */
 	protected $_previewed_blog_id;
@@ -236,7 +270,6 @@ class WP_Customize_Setting {
 	 * Return true if the current site is not the same as the previewed site.
 	 *
 	 * @since 4.2.0
-	 * @access public
 	 *
 	 * @return bool If preview() has been called.
 	 */
@@ -265,7 +298,6 @@ class WP_Customize_Setting {
 	 *
 	 * @since 3.4.0
 	 * @since 4.4.0 Added boolean return value.
-	 * @access public
 	 *
 	 * @return bool False when preview short-circuits due no change needing to be previewed.
 	 */
@@ -379,7 +411,7 @@ class WP_Customize_Setting {
 	 * is called for this setting.
 	 *
 	 * @since 4.4.0
-	 * @access private
+	 *
 	 * @see WP_Customize_Manager::set_post_value()
 	 * @see WP_Customize_Setting::_multidimensional_preview_filter()
 	 */
@@ -426,7 +458,6 @@ class WP_Customize_Setting {
 	 * the first setting previewed will be used to apply the values for the others.
 	 *
 	 * @since 4.4.0
-	 * @access private
 	 *
 	 * @see WP_Customize_Setting::$aggregated_multidimensionals
 	 * @param mixed $original Original root value.
@@ -469,8 +500,6 @@ class WP_Customize_Setting {
 	 *
 	 * @since 3.4.0
 	 *
-	 * @access public
-	 *
 	 * @return false|void False if cap check fails or value isn't set or is invalid.
 	 */
 	final public function save() {
@@ -480,17 +509,19 @@ class WP_Customize_Setting {
 			return false;
 		}
 
+		$id_base = $this->id_data['base'];
+
 		/**
 		 * Fires when the WP_Customize_Setting::save() method is called.
 		 *
-		 * The dynamic portion of the hook name, `$this->id_data['base']` refers to
+		 * The dynamic portion of the hook name, `$id_base` refers to
 		 * the base slug of the setting name.
 		 *
 		 * @since 3.4.0
 		 *
 		 * @param WP_Customize_Setting $this WP_Customize_Setting instance.
 		 */
-		do_action( 'customize_save_' . $this->id_data['base'], $this );
+		do_action( "customize_save_{$id_base}", $this );
 
 		$this->update( $value );
 	}
@@ -534,7 +565,6 @@ class WP_Customize_Setting {
 	 * Validates an input.
 	 *
 	 * @since 4.6.0
-	 * @access public
 	 *
 	 * @see WP_REST_Request::has_valid_params()
 	 *
@@ -576,7 +606,6 @@ class WP_Customize_Setting {
 	 * Get the root value for a setting, especially for multidimensional ones.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 *
 	 * @param mixed $default Value to return if root does not exist.
 	 * @return mixed
@@ -601,7 +630,6 @@ class WP_Customize_Setting {
 	 * Set the root value for a setting, especially for multidimensional ones.
 	 *
 	 * @since 4.4.0
-	 * @access protected
 	 *
 	 * @param mixed $value Value to set as root of multidimensional setting.
 	 * @return bool Whether the multidimensional root was updated successfully.
@@ -768,7 +796,6 @@ class WP_Customize_Setting {
 	 * Retrieves the data to export to the client via JSON.
 	 *
 	 * @since 4.6.0
-	 * @access public
 	 *
 	 * @return array Array of parameters passed to JavaScript.
 	 */
@@ -905,17 +932,27 @@ class WP_Customize_Setting {
 	}
 }
 
-/** WP_Customize_Filter_Setting class */
+/**
+ * WP_Customize_Filter_Setting class.
+ */
 require_once( ABSPATH . WPINC . '/customize/class-wp-customize-filter-setting.php' );
 
-/** WP_Customize_Header_Image_Setting class */
+/**
+ * WP_Customize_Header_Image_Setting class.
+ */
 require_once( ABSPATH . WPINC . '/customize/class-wp-customize-header-image-setting.php' );
 
-/** WP_Customize_Background_Image_Setting class */
+/**
+ * WP_Customize_Background_Image_Setting class.
+ */
 require_once( ABSPATH . WPINC . '/customize/class-wp-customize-background-image-setting.php' );
 
-/** WP_Customize_Nav_Menu_Item_Setting class */
+/**
+ * WP_Customize_Nav_Menu_Item_Setting class.
+ */
 require_once( ABSPATH . WPINC . '/customize/class-wp-customize-nav-menu-item-setting.php' );
 
-/** WP_Customize_Nav_Menu_Setting class */
+/**
+ * WP_Customize_Nav_Menu_Setting class.
+ */
 require_once( ABSPATH . WPINC . '/customize/class-wp-customize-nav-menu-setting.php' );
