@@ -21,7 +21,6 @@ class WP_Date_Query {
 	 * See WP_Date_Query::__construct() for information on date query arguments.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 * @var array
 	 */
 	public $queries = array();
@@ -30,7 +29,6 @@ class WP_Date_Query {
 	 * The default relation between top-level queries. Can be either 'AND' or 'OR'.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 * @var string
 	 */
 	public $relation = 'AND';
@@ -39,7 +37,6 @@ class WP_Date_Query {
 	 * The column to query against. Can be changed via the query arguments.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 * @var string
 	 */
 	public $column = 'post_date';
@@ -48,7 +45,6 @@ class WP_Date_Query {
 	 * The value comparison operator. Can be changed via the query arguments.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 * @var array
 	 */
 	public $compare = '=';
@@ -57,7 +53,6 @@ class WP_Date_Query {
 	 * Supported time-related parameter keys.
 	 *
 	 * @since 4.1.0
-	 * @access public
 	 * @var array
 	 */
 	public $time_keys = array( 'after', 'before', 'year', 'month', 'monthnum', 'week', 'w', 'dayofyear', 'day', 'dayofweek', 'dayofweek_iso', 'hour', 'minute', 'second' );
@@ -73,7 +68,6 @@ class WP_Date_Query {
 	 * @since 3.7.0
 	 * @since 4.0.0 The $inclusive logic was updated to include all times within the date range.
 	 * @since 4.1.0 Introduced 'dayofweek_iso' time type parameter.
-	 * @access public
 	 *
 	 * @param array $date_query {
 	 *     Array of date query clauses.
@@ -151,7 +145,6 @@ class WP_Date_Query {
 	 *                              'comment_date', 'comment_date_gmt'.
 	 */
 	public function __construct( $date_query, $default_column = 'post_date' ) {
-
 		if ( isset( $date_query['relation'] ) && 'OR' === strtoupper( $date_query['relation'] ) ) {
 			$this->relation = 'OR';
 		} else {
@@ -192,7 +185,6 @@ class WP_Date_Query {
 	 * `$defaults`.
 	 *
 	 * @since 4.1.0
-	 * @access public
 	 *
 	 * @param array $queries
 	 * @param array $parent_query
@@ -252,6 +244,8 @@ class WP_Date_Query {
 	 * Checks to see if the current clause has any time-related keys.
 	 * If so, it's first-order.
 	 *
+	 * @since 4.1.0
+	 *
 	 * @param  array $query Query clause.
 	 * @return bool True if this is a first-order clause.
 	 */
@@ -264,7 +258,6 @@ class WP_Date_Query {
 	 * Determines and validates what comparison operator to use.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 *
 	 * @param array $query A date query or a date subquery.
 	 * @return string The comparison operator.
@@ -284,7 +277,6 @@ class WP_Date_Query {
 	 * This method only generates debug notices for these cases.
 	 *
 	 * @since  4.1.0
-	 * @access public
 	 *
 	 * @param  array $date_query The date_query array.
 	 * @return bool  True if all values in the query are valid, false if one or more fail.
@@ -480,7 +472,6 @@ class WP_Date_Query {
 	 * and are only sanitized to remove illegal characters.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 *
 	 * @param string $column The user-supplied column name.
 	 * @return string A validated column name value.
@@ -549,7 +540,6 @@ class WP_Date_Query {
 	 * Generate WHERE clause to be appended to a main query.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 *
 	 * @return string MySQL WHERE clause.
 	 */
@@ -576,7 +566,6 @@ class WP_Date_Query {
 	 * out to maintain parity with the other Query classes.
 	 *
 	 * @since 4.1.0
-	 * @access protected
 	 *
 	 * @return array {
 	 *     Array containing JOIN and WHERE SQL clauses to append to the main query.
@@ -602,7 +591,6 @@ class WP_Date_Query {
 	 * produce the properly nested SQL.
 	 *
 	 * @since 4.1.0
-	 * @access protected
 	 *
 	 * @param array $query Query to parse.
 	 * @param int   $depth Optional. Number of tree levels deep we currently are.
@@ -687,7 +675,6 @@ class WP_Date_Query {
 	 * compatibility while retaining the naming convention across Query classes.
 	 *
 	 * @since  3.7.0
-	 * @access protected
 	 *
 	 * @param  array $query Date query arguments.
 	 * @return array {
@@ -705,7 +692,6 @@ class WP_Date_Query {
 	 * Turns a first-order date query into SQL for a WHERE clause.
 	 *
 	 * @since  4.1.0
-	 * @access protected
 	 *
 	 * @param  array $query        Date query clause.
 	 * @param  array $parent_query Parent query of the current date query.
@@ -740,12 +726,12 @@ class WP_Date_Query {
 		}
 
 		// Range queries.
-		if ( ! empty( $query['after'] ) )
+		if ( ! empty( $query['after'] ) ) {
 			$where_parts[] = $wpdb->prepare( "$column $gt %s", $this->build_mysql_datetime( $query['after'], ! $inclusive ) );
-
-		if ( ! empty( $query['before'] ) )
+		}
+		if ( ! empty( $query['before'] ) ) {
 			$where_parts[] = $wpdb->prepare( "$column $lt %s", $this->build_mysql_datetime( $query['before'], $inclusive ) );
-
+		}
 		// Specific value queries.
 
 		if ( isset( $query['year'] ) && $value = $this->build_value( $compare, $query['year'] ) )
@@ -800,7 +786,6 @@ class WP_Date_Query {
 	 * Builds and validates a value string based on the comparison operator.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 *
 	 * @param string $compare The compare operator to use
 	 * @param string|array $value The value
@@ -843,7 +828,7 @@ class WP_Date_Query {
 
 				return $value[0] . ' AND ' . $value[1];
 
-			default;
+			default:
 				if ( ! is_numeric( $value ) ) {
 					return false;
 				}
@@ -860,7 +845,6 @@ class WP_Date_Query {
 	 * pass a string that will be run through strtotime().
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 *
 	 * @param string|array $datetime       An array of parameters or a strotime() string
 	 * @param bool         $default_to_max Whether to round up incomplete dates. Supported by values
@@ -948,7 +932,6 @@ class WP_Date_Query {
 	 * in order to be able to accurately compare against.
 	 *
 	 * @since 3.7.0
-	 * @access public
 	 *
 	 * @param string $column The column to query against. Needs to be pre-validated!
 	 * @param string $compare The comparison operator. Needs to be pre-validated!
