@@ -1009,7 +1009,7 @@ function wp_print_media_templates() {
 								</div>
 								<label class="setting link-rel">
 									<span><?php _e('Link Rel'); ?></span>
-									<input type="text" data-setting="linkRel" value="{{ data.model.linkClassName }}" />
+									<input type="text" data-setting="linkRel" value="{{ data.model.linkRel }}" />
 								</label>
 								<label class="setting link-class-name">
 									<span><?php _e('Link CSS Class'); ?></span>
